@@ -17,7 +17,7 @@
  * along with QCAD.
  */
 
-include("../Modify.js");
+include("scripts/Modify/Modify.js");
 include("scripts/ShapeAlgorithms.js");
 
 function Explode(guiAction) {
@@ -99,7 +99,6 @@ Explode.explodeSelection = function(di, toolTitle) {
         if (isPointEntity(entity) ||
             isLineEntity(entity) ||
             isArcEntity(entity) ||
-            isCircleEntity(entity) ||
             isViewportEntity(entity)) {
             continue;
         }
@@ -200,6 +199,15 @@ Explode.explodeEntity = function(entity, options) {
         }
     }
 
+    // explode circle into polyline with two arc segments:
+    else if (isCircleEntity(entity)) {
+        var circle = entity.getData().castToShape();
+        polyline = new RPolyline();
+        polyline.appendShape(new RArc(circle.getCenter(), circle.getRadius(), 0.0, Math.PI, false));
+        polyline.appendShape(new RArc(circle.getCenter(), circle.getRadius(), Math.PI, 2*Math.PI, false));
+        ret.push(polyline);
+    }
+
     // explode polyline into line and arc segments:
     else if (isPolylineEntity(entity)) {
         polyline = entity.getData().castToShape();
