@@ -1140,7 +1140,8 @@ WidgetFactory.initLayerCombo = function(comboBox, doc) {
     comboBox.clear();
     comboBox.iconSize = new QSize(32, 16);
     var names = doc.getLayerNames();
-    names.sort(Array.alphaNumericalSorter);
+    names = RS.sortAlphanumerical(names);
+    //names.sort(Array.alphaNumericalSorter);
     for (var i=0; i<names.length; i++) {
         var name = names[i];
         var layer = doc.queryLayer(name);
@@ -1159,7 +1160,8 @@ WidgetFactory.initBlockCombo = function(comboBox, doc, showSpaces) {
 
     comboBox.clear();
     var names = doc.getBlockNames();
-    names.sort(Array.alphaNumericalSorter);
+    //names.sort(Array.alphaNumericalSorter);
+    names = RS.sortAlphanumerical(names);
     for (var i=0; i<names.length; i++) {
         var name = names[i];
         if (showSpaces || !name.startsWith("*")) {
@@ -1203,6 +1205,27 @@ WidgetFactory.initVAlignCombo = function(comboBox) {
     comboBox.addItem(qsTr("Bottom"), RS.VAlignBottom);
 };
 
+WidgetFactory.initOrientationCombo = function(comboBox) {
+    comboBox.clear();
+
+    if (RSettings.isQt(5)) {
+        comboBox.addItem("↻ " + qsTr("Clockwise"), RS.CW);
+        comboBox.addItem("↺ " + qsTr("Counterclockwise"), RS.CCW);
+    }
+    else {
+        comboBox.addItem(qsTr("Clockwise"), RS.CW);
+        comboBox.addItem(qsTr("Counterclockwise"), RS.CCW);
+    }
+};
+
+WidgetFactory.initArcSymbolTypeCombo = function(comboBox) {
+    comboBox.clear();
+
+    comboBox.addItem(qsTr("Preceding"), 0);
+    comboBox.addItem(qsTr("Above"), 1);
+    comboBox.addItem(qsTr("None"), 2);
+};
+
 WidgetFactory.installComboBoxEventFilter = function(widget) {
     if (isNull(widget)) {
         return;
