@@ -1405,64 +1405,22 @@ Array.prototype.sortNumerical = function() {
 //    }
 //};
 
-/* alphanum.js (C) Brian Huisman
- * Based on the Alphanum Algorithm by David Koelle
- * The Alphanum Algorithm is discussed at http://www.DaveKoelle.com
- *
- * Distributed under same license as original
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+/**
+ * Obsolete.
+ * Use RS.compareAlphanumerical instead.
  */
 Array.alphaNumericalSorter = function(a, b) {
-    function chunkify(t) {
-        var tz = new Array();
-        var x = 0, y = -1, n = 0, i, j;
-
-        while (i = (j = t.charAt(x++)).charCodeAt(0)) {
-            var m = (i == 46 || (i >=48 && i <= 57));
-            if (m !== n) {
-                tz[++y] = "";
-                n = m;
-            }
-            tz[y] += j;
-        }
-        return tz;
-    }
-
-    var aa = chunkify(a.toLowerCase());
-    var bb = chunkify(b.toLowerCase());
-
-    for (x = 0; aa[x] && bb[x]; x++) {
-        if (aa[x] !== bb[x]) {
-            var c = Number(aa[x]), d = Number(bb[x]);
-            if (c == aa[x] && d == bb[x]) {
-                return c - d;
-            } else return (aa[x] > bb[x]) ? 1 : -1;
-        }
-    }
-    return aa.length - bb.length;
+    return RS.compareAlphanumerical(a, b);
 };
 
 /**
  * Sorts this array with string items (case insensitive)
  */
-Array.prototype.sortCaseInsensitive = function() {
-    Array.prototype.sort.call(this, function (a, b) {
-        return a.toLowerCase().localeCompare(b.toLowerCase());
-    });
-};
+//Array.prototype.sortCaseInsensitive = function() {
+//    Array.prototype.sort.call(this, function (a, b) {
+//        return a.toLowerCase().localeCompare(b.toLowerCase());
+//    });
+//};
 
 /* Finds the intersection of two sorted arrays.
  *
@@ -2169,7 +2127,6 @@ function restoreOverrideCursor() {
 }
 
 function initUserShortcuts() {
-    var settings = RSettings.getQSettings();
     var keys = RSettings.getAllKeys("Shortcuts");
 
     var i, key, action;
@@ -2180,14 +2137,25 @@ function initUserShortcuts() {
         if (isNull(action)) {
             continue;
         }
-        var scStringList = settings.value("Shortcuts/" + key);
+
+        var match = action.getScriptFile().contains("OpenFile");
+
+        var scStringList = RSettings.getValue("Shortcuts/" + key);
+
+        if (match) qDebug("scStringList", scStringList);
 
         // explicitely no shortcuts:
         if (isNull(scStringList)) {
+            if (match) qDebug("explicitely no shortcuts");
             action.setShortcuts([]);
             continue;
         }
 
+        if (match) qDebug("setting shortcuts to ", scStringList);
+
+        //action.setShortcutsFromStrings(scStringList);
+        //action.setShortcuts(scStringList);
+
         var scList = [];
         for (var k=0; k<scStringList.length; k++) {
             var sc = new QKeySequence(scStringList[k]);
@@ -2204,7 +2172,7 @@ function initUserShortcuts() {
         if (isNull(action)) {
             continue;
         }
-        var cmStringList = settings.value("Commands/" + key);
+        var cmStringList = RSettings.getValue("Commands/" + key);
 
         // explicitely no commands:
         if (isNull(cmStringList)) {
